<?php 
echo "Stitch - (c) 2008 Dominic Szablewski\n";

if( count($argv) < 3 ) {
	echo "Usage: stitch.php <in glob> <out.png> [<images per row> <w border> <h border> <w size> <h size>]\n";
	exit;
}
$imgsPerRow = $argv[3] ? intval($argv[3]) : 60;
$borderW = $argv[4] ? intval($argv[4]) : 0;
$borderH = $argv[5] ? intval($argv[5]) : 0;

$files = glob( $argv[1] );
if( empty($files) ) {
	echo "\nError: No input files found at ".$argv[1]."\n";
	die();
}
sort( $files );
list( $origW, $origH, $imgType ) = getImageSize( $files[0] );
if( $imgType != IMAGETYPE_JPEG && $imgType != IMAGETYPE_PNG ) {
	echo "\nError: ".$files[0]." is not a JPEG or PNG  image\n";
	die();
}

$width = $argv[6] ? $argv[6] : $origW;
$height = $argv[7] ? $argv[7] : $origH;

// Don't ask me why, but on some PCs a foreach loop like 
// foreach( $files as $i => $file )
// didn't work as expected. So here's the workaround...
$rows = array();
$i = 0;
foreach( $files as $file ) {
	$rows[$i/$imgsPerRow][] = $file;
	$i++;
}

$finalH = ceil(count($files)/$imgsPerRow) * $height + ceil(count($files)/$imgsPerRow) * $borderH;
$finalW = $width * $imgsPerRow + $imgsPerRow * $borderW - $borderW;

echo "Image Size: $finalW x $finalH\n";
echo "Aspect: 1:".round($finalH/$finalW,3)." / ".round($finalW/$finalH,3).":1\n";


$comp = imageCreateTrueColor( $finalW, $finalH );
$y = 0;
foreach( $rows as $row ) {
	$x = 0;
	echo sprintf( "\n%03d", $y );
	foreach( $row as $file ) {
		echo "#";
		if( $imgType == IMAGETYPE_JPEG ) {
			$img = @imageCreateFromJPEG( $file );
		} else if( $imgType == IMAGETYPE_PNG ) {
			$img = @imageCreateFromPNG( $file );
		}
		if( !$img ) {
			echo "\nError: Failed to open $file\n";
			die();
		}
		imageCopyResampled( 
			$comp, $img, 
			$x * $width + $x * $borderW, 
			$y * $height + $y * $borderH, 
			0, 0, 
			$width, $height, 
			$origW, $origH
		);
		
		imageDestroy( $img );
		$x++;
	}
	$y++;
}
echo "\nwriting ".$argv[2];
imagePNG( $comp, $argv[2] );
imageDestroy( $comp );

?>